@@ -8,6 +8,8 @@
 module Options where
 
 import System.Console.GetOpt
+import System.Log.Logger
+import Control.Monad.State (liftIO)
 
 import qualified Annex
 import Types
@@ -27,12 +29,15 @@ commonOptions =
 	, Option ['q'] ["quiet"] (NoArg (setquiet True))
 		"avoid verbose output"
 	, Option ['v'] ["verbose"] (NoArg (setquiet False))
-		"allow verbose output"
-	, Option ['b'] ["backend"] (ReqArg setdefaultbackend paramName)
-		"specify default key-value backend to use"
+		"allow verbose output (default)"
+	, Option ['d'] ["debug"] (NoArg (setdebug))
+		"show debug messages"
+	, Option ['b'] ["backend"] (ReqArg setforcebackend paramName)
+		"specify key-value backend to use"
 	]
 	where
 		setforce v = Annex.changeState $ \s -> s { Annex.force = v }
 		setfast v = Annex.changeState $ \s -> s { Annex.fast = v }
 		setquiet v = Annex.changeState $ \s -> s { Annex.quiet = v }
-		setdefaultbackend v = Annex.changeState $ \s -> s { Annex.defaultbackend = Just v }
+		setforcebackend v = Annex.changeState $ \s -> s { Annex.forcebackend = Just v }
+		setdebug = liftIO $ updateGlobalLogger "" $ setLevel DEBUG
